import { SheetJSInternalUtils } from '../../../../utils/outerTableComponents/files/SheetJS/SheetJSInternalUtils';
import { FilterInternalUtils } from '../../../../utils/outerTableComponents/filter/rows/filterInternalUtils';
import { SheetJSImport } from '../../../../utils/outerTableComponents/files/SheetJS/SheetJSImport';
import { ACCEPTED_FILE_FORMATS, DEFAULT_FILE_FORMATS } from '../../../../consts/fileFormats';
import { CSVImport } from '../../../../utils/outerTableComponents/files/CSV/CSVImport';
export class FileImportButtonEvents {
    static importFile(at, file, formats, options) {
        if (formats.find((extension) => file.name.endsWith(extension))) {
            if (at._visiblityInternal.rows)
                FilterInternalUtils.unsetAllFilters(at);
            if (file.name.endsWith('.csv')) {
                CSVImport.import(at, file, options);
            }
            else {
                SheetJSInternalUtils.execFuncWithExtractorModule(SheetJSImport.import.bind(this, at, file));
            }
            // in a timeout as at.shadowRoot.contains does not work immediately
            setTimeout(() => FilterInternalUtils.completeReset(at), 6);
        }
    }
    static inputChange(at, options, event) {
        var _a;
        const inputElement = event.target;
        const file = (_a = inputElement.files) === null || _a === void 0 ? void 0 : _a[0];
        FileImportButtonEvents.importFile(at, file, ACCEPTED_FILE_FORMATS, options);
        inputElement.value = ''; // resetting to prevent Chrome issue of not being able to upload same file twice
    }
    static getAcceptedFormats(importOptions) {
        return (importOptions === null || importOptions === void 0 ? void 0 : importOptions.formats) && importOptions.formats.length > 0 ? importOptions.formats : DEFAULT_FILE_FORMATS;
    }
    static triggerImportPrompt(at, importOptions) {
        const inputElement = at._files.inputElementRef;
        const acceptedFormats = FileImportButtonEvents.getAcceptedFormats(importOptions);
        inputElement.accept = acceptedFormats.map((format) => `.${format}`).join(',');
        inputElement.onchange = FileImportButtonEvents.inputChange.bind(this, at, importOptions === null || importOptions === void 0 ? void 0 : importOptions.overwriteOptions);
        inputElement.click();
    }
    static setEvents(at, buttonElement, importOptions) {
        buttonElement.onclick = FileImportButtonEvents.triggerImportPrompt.bind(this, at, importOptions);
    }
}
//# sourceMappingURL=fileImportButtonEvents.js.map