import { ARROW_DOWN_SVG_STRING } from '../../../../consts/icons/arrowDownIconSVGString';
import { GenericElementUtils } from '../../../../utils/elements/genericElementUtils';
import { RowsPerPageSelectButtonEvents } from './rowsPerPageSelectButtonEvents';
import { ElementStyle } from '../../../../utils/elements/elementStyle';
import { SVGIconUtils } from '../../../../utils/svgIcons/svgIconUtils';
export class RowsPerPageSelectButtonElement {
    // prettier-ignore
    static applyStyle(element, rowsPerPageSelect, elementName, cssState) {
        const statefulStyle = rowsPerPageSelect[elementName];
        ElementStyle.unsetAllCSSStates(element, statefulStyle);
        Object.assign(element.style, statefulStyle[cssState]);
    }
    // prettier-ignore
    static applyStylesOnElements(button, cssState, rowsPerPageSelect) {
        if (!rowsPerPageSelect)
            return;
        if (rowsPerPageSelect.button) {
            RowsPerPageSelectButtonElement.applyStyle(button, rowsPerPageSelect, 'button', cssState);
        }
        if (rowsPerPageSelect.buttonText) {
            const buttonText = button.children[0];
            RowsPerPageSelectButtonElement.applyStyle(buttonText, rowsPerPageSelect, 'buttonText', cssState);
        }
        if (rowsPerPageSelect.buttonArrow) {
            const buttonArrow = button.children[1];
            RowsPerPageSelectButtonElement.applyStyle(buttonArrow, rowsPerPageSelect, 'buttonArrow', cssState);
        }
    }
    static processStatefulStyle(statefulCSS) {
        var _a, _b;
        (_a = statefulCSS.hover) !== null && _a !== void 0 ? _a : (statefulCSS.hover = statefulCSS.default);
        (_b = statefulCSS.click) !== null && _b !== void 0 ? _b : (statefulCSS.click = statefulCSS.hover);
    }
    static processAndApplyDefaultStyle(element, styling) {
        if (styling) {
            RowsPerPageSelectButtonElement.processStatefulStyle(styling);
            Object.assign(element.style, styling.default);
        }
    }
    static createButtonArrow(pagination) {
        var _a;
        const arrow = document.createElement('div');
        arrow.id = RowsPerPageSelectButtonElement.ARROW_CONTAINER_ID;
        arrow.classList.add(GenericElementUtils.NOT_SELECTABLE_CLASS);
        RowsPerPageSelectButtonElement.processAndApplyDefaultStyle(arrow, (_a = pagination.styles.rowsPerPageSelect) === null || _a === void 0 ? void 0 : _a.buttonArrow);
        // WORK - need to show how to color this in documentation
        const arrowDownIcon = SVGIconUtils.createSVGElement(ARROW_DOWN_SVG_STRING);
        arrowDownIcon.id = RowsPerPageSelectButtonElement.ARROW_ICON_ID;
        arrow.appendChild(arrowDownIcon);
        return arrow;
    }
    static updateButtonText(optionsButton, rowsPerPage) {
        const text = optionsButton.children[0];
        text.innerText = rowsPerPage;
    }
    static createButtonText(pagination) {
        var _a;
        const { isAllRowsOptionSelected, rowsPerPageOptionsItemText, rowsPerPage, styles } = pagination;
        const text = document.createElement('div');
        text.id = RowsPerPageSelectButtonElement.TEXT_ID;
        text.classList.add(GenericElementUtils.NOT_SELECTABLE_CLASS);
        RowsPerPageSelectButtonElement.processAndApplyDefaultStyle(text, (_a = styles.rowsPerPageSelect) === null || _a === void 0 ? void 0 : _a.buttonText);
        text.innerText = isAllRowsOptionSelected ? rowsPerPageOptionsItemText[0] : String(rowsPerPage);
        return text;
    }
    static createOptionsButton(pagination) {
        var _a;
        const optionsButton = document.createElement('div');
        optionsButton.id = RowsPerPageSelectButtonElement.BUTTON_ID;
        RowsPerPageSelectButtonElement.processAndApplyDefaultStyle(optionsButton, (_a = pagination.styles.rowsPerPageSelect) === null || _a === void 0 ? void 0 : _a.button);
        return optionsButton;
    }
    static create(at) {
        const optionsButton = RowsPerPageSelectButtonElement.createOptionsButton(at._pagination);
        optionsButton.appendChild(RowsPerPageSelectButtonElement.createButtonText(at._pagination));
        optionsButton.appendChild(RowsPerPageSelectButtonElement.createButtonArrow(at._pagination));
        setTimeout(() => RowsPerPageSelectButtonEvents.setEvents(at, optionsButton));
        return optionsButton;
    }
}
RowsPerPageSelectButtonElement.BUTTON_ID = 'rows-per-page-select-button';
RowsPerPageSelectButtonElement.ARROW_CONTAINER_ID = 'rows-per-page-select-button-arrow-container';
RowsPerPageSelectButtonElement.ARROW_ICON_ID = 'rows-per-page-select-button-arrow-icon';
RowsPerPageSelectButtonElement.TEXT_ID = 'rows-per-page-select-button-text';
//# sourceMappingURL=rowsPerPageSelectButtonElement.js.map