import { ElementStyle } from './elementStyle';
export class StatefulCSSEvents {
    static mouseUp(styles, inactiveClass, element) {
        if (inactiveClass && element.classList.contains(inactiveClass))
            return;
        ElementStyle.unsetAllCSSStates(element, styles);
        Object.assign(element.style, styles.default);
        Object.assign(element.style, styles.hover);
    }
    static mouseDown(styles, inactiveClass, element) {
        if (inactiveClass && element.classList.contains(inactiveClass))
            return;
        Object.assign(element.style, styles.click);
    }
    static mouseLeave(styles, inactiveClass, element) {
        if (inactiveClass && element.classList.contains(inactiveClass))
            return;
        ElementStyle.unsetAllCSSStates(element, styles);
        Object.assign(element.style, styles.default);
    }
    static mouseEnter(styles, inactiveClass, element) {
        if (inactiveClass && element.classList.contains(inactiveClass))
            return;
        Object.assign(element.style, styles.hover);
    }
    static setEvents(element, styles, inactiveClass) {
        element.addEventListener('mouseenter', StatefulCSSEvents.mouseEnter.bind(this, styles, inactiveClass, element));
        element.addEventListener('mouseleave', StatefulCSSEvents.mouseLeave.bind(this, styles, inactiveClass, element));
        element.addEventListener('mousedown', StatefulCSSEvents.mouseDown.bind(this, styles, inactiveClass, element));
        element.addEventListener('mouseup', StatefulCSSEvents.mouseUp.bind(this, styles, inactiveClass, element));
    }
}
//# sourceMappingURL=statefulCSSEvents.js.map