import { ColumnSettingsUtils } from '../columnSettings/columnSettingsUtils';
import { FocusedCellUtils } from '../focusedElements/focusedCellUtils';
import { ChangeColumnType } from '../columnType/changeColumnType';
import { CellHighlightUtils } from '../color/cellHighlightUtils';
import { CellElement } from '../../elements/cell/cellElement';
import { HeaderText } from '../columnDetails/headerText';
import { FireEvents } from '../events/fireEvents';
import { MoveUtils } from './moveUtils';
export class MoveColumn {
    // prettier-ignore
    static overwriteDataElements(at, targetElements, targetColIndex, sourceCellText) {
        const overwrittenText = [];
        targetElements.slice(1).forEach((element, rowIndex) => {
            const relativeIndex = rowIndex + 1;
            const sourceText = sourceCellText[relativeIndex];
            const oldText = MoveUtils.setNewElementText(at, sourceText, element, targetColIndex, relativeIndex);
            overwrittenText.push(oldText);
        });
        return overwrittenText;
    }
    // prettier-ignore
    static changeSettings(at, targetColIndex, targetHeader, targetColumnDetails, sourceType) {
        HeaderText.onAttemptChange(at, targetHeader, targetColIndex, { colMove: true });
        if (sourceType !== targetColumnDetails.activeType) {
            ChangeColumnType.change.bind(at)(sourceType.name, targetColIndex);
        }
    }
    // prettier-ignore
    static overwrite(at, targetColumnDetails, targetColIndex, sourceCellText, sourceType, sourceColWidth) {
        const overwrittenText = [];
        const { elements: targetElements, activeType: targetType } = targetColumnDetails;
        const oldHeaderText = MoveUtils.setNewElementText(at, sourceCellText[0], targetElements[0], targetColIndex, 0);
        overwrittenText.push(oldHeaderText);
        MoveColumn.changeSettings(at, targetColIndex, targetElements[0], targetColumnDetails, sourceType);
        const overwrittenDataText = MoveColumn.overwriteDataElements(at, targetElements, targetColIndex, sourceCellText);
        overwrittenText.push(...overwrittenDataText);
        const overwrittenWidth = targetElements[0].style.width;
        targetElements[0].style.width = sourceColWidth; // this is done because column widths are not stored in state (REF-35)
        return { overwrittenText, overwrittenType: targetType, overwrittenWidth };
    }
    static firstChangeSettingsIfSettingsChanged(at, columnIndex) {
        const { areSettingsDifferent } = ColumnSettingsUtils.parseSettingsChange(at);
        if (areSettingsDifferent) {
            const currentColumn = at._columnsDetails[columnIndex];
            HeaderText.onAttemptChange(at, currentColumn.elements[0], columnIndex);
        }
    }
    // prettier-ignore
    static move(at, columnIndex, isToRight) {
        MoveColumn.firstChangeSettingsIfSettingsChanged(at, columnIndex);
        const currentColumn = at._columnsDetails[columnIndex];
        CellHighlightUtils.fade(currentColumn.elements[0], currentColumn === null || currentColumn === void 0 ? void 0 : currentColumn.headerStateColors.default);
        const siblingIndex = isToRight ? columnIndex + 1 : columnIndex - 1;
        const siblingColumn = at._columnsDetails[siblingIndex];
        const siblingColumnText = siblingColumn.elements.map((element) => CellElement.getText(element));
        const siblingColumnWidth = siblingColumn.elements[0].style.width;
        // overwrite current column using sibling column
        const overwritten = MoveColumn.overwrite(at, currentColumn, columnIndex, siblingColumnText, siblingColumn.activeType, siblingColumnWidth);
        FocusedCellUtils.set(at._focusedElements.cell, siblingColumn.elements[0], 0, siblingIndex);
        // overwrite sibling column using overwritten content
        MoveColumn.overwrite(at, siblingColumn, siblingIndex, overwritten.overwrittenText, overwritten.overwrittenType, overwritten.overwrittenWidth);
        setTimeout(() => FireEvents.onColumnsUpdate(at));
    }
}
//# sourceMappingURL=moveColumn.js.map